@@ -46,7 +46,7 @@ avisContributorsSummary<- function ()
 avisContributorAggregatedObservations<- function (contributor_id)
 {
   doc<-XML::htmlParse(paste ("http://proyectoavis.com/cgi-bin/ficha_usuario.cgi?id_usuario=", contributor_id, sep=""))
-  nodes <- XML::getNodeSet(doc, "//table[@class=\"observaciones1\"]/tr")
+  nodes <- XML::getNodeSet(doc, "//table[@class=\"observaciones\"][2]//tr")
   df<-data.frame()
   
   for(node in nodes[2:length(nodes)]){
